# -*- coding: utf-8 -*-
"""
Created on Sun Aug  5 14:26:44 2018

@author: erwan
"""

from __future__ import print_function, absolute_import, division, unicode_literals
from radis.tools.database import load_spec
from radis.spectrum.operations import crop
from radis.test.utils import getTestFile
import pytest

@pytest.mark.fast
def test_crop(verbose=True, *args, **kwargs):
    ''' Test that update can correctly recompute missing quantities '''

    # 1) A crop example in the same unit as the one stored

    # Work with a Spectrum object that was generated by Specair
    s = load_spec(getTestFile('N2C_specair_380nm.spec'))
    # Focus on N2(C->B), v'=0, v''=2 band:
    s.crop(376, 381, 'nm')
    
    w = s.get_wavelength()
    assert w.min() >= 360
    assert w.max() <= 382
    
    # 2) A crop example in different unit as the one stored

    # Work with a Spectrum object that was generated by Specair
    s = load_spec(getTestFile('CO_Tgas1500K_mole_fraction0.01.spec'), binary=True)
    # Focus on N2(C->B), v'=0, v''=2 band:
    s.crop(4530, 4533, 'nm')
    
    w = s.get_wavelength()
    assert w.min() >= 4530
    assert w.max() <= 4533
    
    return True


def test_cut_recombine(verbose=True, *args, **kwargs):
    ''' 
    Use :func:`~radis.spectrum.operations.crop` and :func:`~radis.los.slabs.MergeSlabs`
    to cut a Spectrum and recombine it
    
    Assert we still get the same spectrum at the end
    '''
    from radis import MergeSlabs

    s = load_spec(getTestFile('CO_Tgas1500K_mole_fraction0.01.spec'), binary=True)
    # Cut in half
    cut = 2177
    s1 = crop(s, 2000, cut, 'cm-1', inplace=False)
    s2 = crop(s, cut, 2300, 'cm-1', inplace=False)

    # Recombine
    s_new = MergeSlabs(s1, s2, resample_wavespace='full', out_of_bounds='transparent')
    
    # Compare
    assert s.compare_with(s_new, spectra_only=True, plot=False, verbose=verbose)
    

def _run_testcases(verbose=True, *args, **kwargs):
    ''' Test procedures
    '''

    test_crop(verbose=verbose, *args, **kwargs)
    test_cut_recombine(verbose=verbose, *args, **kwargs)
    return True

if __name__ == '__main__':
    
    _run_testcases()
    